# intaqt

Requirements
------------
Python >= 3.7

## Setup
------------
Install from pip:

```
python3 -m pip install intaqt
```

## Configuration
------------
API_KEY: Your project API key 

STATUS: Either 'Error' or 'Ok'